@@ -169,6 +169,7 @@ def fetch_suggestion_code(
 ):
     url = f"{backend_url}/{completions_enpdoint}"
 
+    logger.debug(f"Fetching code for query: {queries}")
     try:
         res = requests.post(
             url,
@@ -179,7 +180,7 @@ def fetch_suggestion_code(
                 "session_id": session_id,
                 "auth_token": auth_token,
             },
-            # timeout=suggestions_timeout,
+            # retries=1,
         )
 
         if res.status_code >= 400:
@@ -299,9 +300,11 @@ class JupyterCogramTokenHandler(IPythonHandler):
 
         log_launch = bool_arg(self.request, "log_launch")
 
+        response = None
         if token is not None:
             logger.debug(f"Checking if token is valid against API: {token}")
-            token_valid = post_auth_token(token, log_launch=log_launch)
+            response = post_auth_token(token, log_launch=log_launch)
+            token_valid = response.status_code == 200
         else:
             token_valid = False
 
@@ -313,10 +316,10 @@ class JupyterCogramTokenHandler(IPythonHandler):
                 "auth_token": token,
             }
         else:
-            status = 404
+            status = response.status_code
             response = {
-                "status": status,
-                "message": "Token not found.",
+                "status": response.status_code,
+                "error": response.json().get("error", "N/A"),
                 "auth_token": None,
             }
 
